@@ -1,15 +1,14 @@
 from __future__ import annotations
 
-import jijmodeling as jm
-import numpy as np
 import typing as tp
 import warnings
 
+import numpy as np
 
 from jijbench.elements.base import Number
 from jijbench.functions.concat import Concat
-from jijbench.solver.jijzept import SampleSet
 from jijbench.node.base import FunctionNode
+from jijbench.solver.jijzept import SampleSet
 
 
 def _is_success_list(sampleset: SampleSet, opt_value: int | float) -> list[bool]:
@@ -112,7 +111,7 @@ class TimeToSolution(Metrics):
         Args:
             inputs (list[SampleSet]): A list of SampleSet objects.
             pr (float): The probability of obtaining a solution.
-            opt_value (int or float): The optimal value.
+            opt_value (int | float): The optimal value.
             base (str): The type of time to solution.
 
         Returns:
@@ -156,7 +155,7 @@ class TimeToSolution(Metrics):
         Args:
             inputs (list[SampleSet]): A list of SampleSet objects.
             pr (float): The probability of obtaining a solution.
-            opt_value (int or float): The optimal value.
+            opt_value (int | float): The optimal value.
             base (str): The type of time to solution.
 
         Returns:
@@ -206,7 +205,7 @@ class SuccessProbability(Metrics):
 
         Args:
             inputs (list[SampleSet]): A list of SampleSet objects.
-            opt_value (int or float): The optimal value.
+            opt_value (int | float): The optimal value.
 
         Returns:
             Number: The success probability.
@@ -218,7 +217,7 @@ class SuccessProbability(Metrics):
 
         Args:
             inputs (list[SampleSet]): A list of SampleSet objects.
-            opt_value (int or float): The optimal value.
+            opt_value (int | float): The optimal value.
 
         Returns:
             Number: The success probability.
@@ -259,6 +258,7 @@ class ResidualEnergy(Metrics):
     """Residual energy.
     The residual energy is defined as the mean of the objective function minus the optimal value.
     """
+
     def __call__(self, inputs: list[SampleSet], opt_value: int | float) -> Number:
         return super().__call__(inputs, opt_value=opt_value)
 
